; FU_colorize-prep.scm
; Creates layer over original to use for 
; colorization, both layers in MULTIPLY-MODE.
; Will flatten any layers prior to starting...
; After script is run, choose your color and brush
; and start painting. Just a handy shortcut, 
; especially useful when colorizing line art.
;
; version 1.0
; (c)2008 by Paul Sherman
; distributed by gimphelp.org
; Last edited/tested on 07/23/2010 on GIMP-2.6.10
;
; --------------------------------------------------------------------
; This program is free software; you can redistribute it and/or modify
; it under the terms of the GNU General Public License as published by
; the Free Software Foundation; either version 2 of the License, or
; (at your option) any later version.
;
; This program is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
;
; You should have received a copy of the GNU General Public License
; along with this program; if not, write to the Free Software
; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
; --------------------------------------------------------------------

(define (colorize-prep image layer)
	(gimp-image-undo-group-start image)
	(gimp-selection-all image) 				; select all
	(define LayerBase (car(gimp-image-flatten image)))	; then flatten
								; now ready to go...
	(gimp-layer-add-alpha LayerBase)
	(define new-layer (car (gimp-layer-copy LayerBase TRUE)))
	(gimp-image-add-layer image new-layer 0)
	(gimp-drawable-set-name new-layer "Color-Me")
	(gimp-drawable-fill new-layer TRANSPARENT-FILL)

	(gimp-selection-all image)
	(gimp-image-set-active-layer image new-layer)

	(gimp-layer-set-mode LayerBase MULTIPLY-MODE)
	(gimp-layer-set-mode new-layer MULTIPLY-MODE)
	(gimp-displays-flush)
	(gimp-image-undo-group-end image))


(script-fu-register "colorize-prep"
	"<Image>/Script-Fu/Prepare for Colorize"
        "Creates layer to paint over original, both layers set to multiply-mode. Top layer is transparent and you can use brush to paint without destroying edges of artwork on the original layer underneath.\n\nby Paul Sherman\ngimphelp.org" 
        "Paul Sherman"
        "(C) 2008, Paul Sherman <psherma1@rochester.rr.com>"
        "01/07/2008"
	"RGB* GRAY*"
	SF-IMAGE "The image" 0
	SF-DRAWABLE "The Layer" 0
)
	






