; FU_effects-layer_layer-quick-border.scm
; version 1.0 [gimphelp.org]
; last modified/tested by Paul Sherman
; 07/23/2010 on GIMP-2.6.10
;
; This is a vastly simplified version of the the border script,
; part of layer-effects.scm. I found default settings for this 
; extremely useful but really did not want the huge interface or
; associated overhead -- so I packed it into this little handy version.
;
; 1.0 is the initial release
;
; ---------------------------------------------------------------------
; This program is free software; you can redistribute it and/or modify
; it under the terms of the GNU General Public License as published by
; the Free Software Foundation; either version 2 of the License, or
; (at your option) any later version.  
; 
; This program is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
; 
; You should have received a copy of the GNU General Public License
; along with this program; if not, write to the Free Software
; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
; ---------------------------------------------------------------------

(define (script_fu_layer_quick_border
                   img
                   layer 
		   		   link?
         )

  (let* (
         (width (car (gimp-image-width img)) ((gimp-drawable-width layer)))
         (height (car (gimp-image-height img)) ((gimp-drawable-height layer)))
         (border-layer (car (gimp-layer-new img width height RGBA-IMAGE "Border Line" 100 0)))
		 (currentselectionAB)
		 (selectionalpha)
		 (wl)
		 (wr)
		 (position)
		 (selectioninner)
		 (result-layer)
        )

    (gimp-image-undo-group-start img)
    (set! currentselectionAB (car(gimp-selection-save img)))
    (gimp-selection-none img)
    (gimp-layer-resize-to-image-size layer)

    (gimp-image-add-layer img border-layer -1)
    (gimp-drawable-fill border-layer TRANS-IMAGE-FILL)
    (gimp-selection-layer-alpha layer)

    (set! selectionalpha (car(gimp-selection-save img)))
    (set! wl (- (/ 1 2) (fmod (/ 1 2) 1))); left width
    (set! wr (+ (/ 1 2) (fmod (/ 1 2) 1))); right width = biggest if uneven
	(set! position 0)

	(gimp-selection-shrink img (- wl position))
	(set! selectioninner (car (gimp-selection-save img)))	
	(gimp-selection-load selectionalpha)
	(gimp-selection-grow img (+ position wr))
	(gimp-selection-combine selectioninner 1) 	 	 

    (if (< (car (gimp-selection-is-empty img)) 0)
        (gimp-message "The selection is empty. Abort.")
        (begin
          (gimp-edit-fill border-layer WHITE-IMAGE-FILL)
          (set! result-layer (car (script_fu_layer_effects_color_overlay img border-layer '(0 0 0) 100 0 link? TRUE)))
          (gimp-drawable-fill border-layer TRANS-IMAGE-FILL)
          (set! border-layer (car (gimp-image-merge-down img result-layer EXPAND-AS-NECESSARY)))
        )
    )

    (gimp-image-remove-channel img selectioninner); these four lines are new in version 0.6a
    (gimp-image-remove-channel img selectionalpha)

    (gimp-selection-load currentselectionAB) 
    (gimp-image-remove-channel img currentselectionAB)
    (if (= link? TRUE)(gimp-drawable-set-linked border-layer TRUE))
    (if (= link? TRUE)(gimp-drawable-set-linked layer TRUE))
	(if (= link? TRUE)(gimp-image-merge-visible-layers img 1))
    (gimp-image-undo-group-end img)
    ;(gimp-image-set-active-layer img layer)
    (gimp-displays-flush)
    (list border-layer)
  )
)

(script-fu-register "script_fu_layer_quick_border"
  "<Image>/Script-Fu/Effects Layer/Quick Border"
  "Quick Border effect on a layer - gives a nice edge, great for enhancing graphic images.\n\nby Paul Sherman\ngimphelp.org"
  "Paul Sherman <psherman2001@gmail.com>"
  "Paul Sherman"
  "Dec, 2008"
  "RGBA"
  SF-IMAGE      "Image"               0
  SF-DRAWABLE   "Drawable"            0
  SF-TOGGLE     "Merge Border Layer?" TRUE
)
